@@ -10,7 +10,7 @@
 use 5.014;
 use utf8;
 package App::SpreadRevolutionaryDate::MsgMaker::PromptUser;
-$App::SpreadRevolutionaryDate::MsgMaker::PromptUser::VERSION = '0.16';
+$App::SpreadRevolutionaryDate::MsgMaker::PromptUser::VERSION = '0.17';
 # ABSTRACT: MsgMaker class for L<App::SpreadRevolutionaryDate> to build message by prompting user
 
 use Moose;
@@ -33,11 +33,14 @@ has 'default' => (
 around BUILDARGS => sub {
   my ($orig, $class, %args) = @_;
 
-  # Get sure locale has .mo file
   if ($args{locale}) {
+    # Get sure locale has .mo file
     my ($volume, $directory, $file) = File::Spec->splitpath(__FILE__);
     my $locale_mo = File::Spec->catfile($directory, '..', '..', '..', 'LocaleData', $args{locale}, 'LC_MESSAGES', 'App-SpreadRevolutionaryDate.mo');
-    $args{locale} = '' unless -f $locale_mo;
+    $args{locale} = 'fr' unless -f $locale_mo;
+  } else {
+    # Defaults to French
+    $args{locale} = 'fr';
   }
 
   # Do not pass default => undef to force default in attribute definition
@@ -103,7 +106,7 @@ App::SpreadRevolutionaryDate::MsgMaker::PromptUser - MsgMaker class for L<App::S
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 METHODS
 
